'
' update_jobs.vbs
' Copyright (c) 2012 DataFlux Corporation LLC
'
' This updates the Web Studio job files in the server's working directory
' from the originals in the installation's share directory.
'

' command-line options
Set args = WScript.Arguments
' install mode
install = False
if args.Count > 0 Then
    If args(0) = "-i" Then
        install = True
    End If
End If

' find root of installation 
Set fso = CreateObject("Scripting.FileSystemObject")
bindir = fso.GetFile(WScript.ScriptFullName).ParentFolder
home = fso.GetFolder(bindir).ParentFolder

' file locations
cfgFile = home & "\etc\repositories\SASMDM.rcf"
upCfg = home & "\etc\update_jobs.cfg"
jobSrc = home & "\share\sasmdm"

' read config to get paths
Set XMLDoc = CreateObject("Microsoft.XMLDOM")
' loads the whole file now before continuing
XMLDoc.async = False
XMLDoc.validateOnParse = False
XMLDoc.load(cfgFile)

' Show XML parse error if there is any.
If XMLDoc.parseError.errorCode <> 0 Then
    msgTitle = "Update MDM jobs"
    addMsg =  "line " & XMLDoc.parseError.line & ": " & XMLDoc.parseError.reason
    If install Then
        WScript.Echo "Unable to parse repository configuration."
        WScript.Echo(addMsg)
    Else 
        MsgBox "Unable to parse repository configuration. " & addMsg, 48, msgTitle
    End If
    Wscript.Quit 1
End If

' VaultPath = File Storage = job root
Set nodes = XMLDoc.selectNodes("/VaultRepositoryInfo/VaultPath")
If nodes.length <> 0 Then
    Set node = nodes.Item(0)
    jobsRoot = node.text
End If

' no file storage?
If jobsRoot = "" Then
    jobsRoot = home & "\var"
End If

' counters for file update operations
numCopied = 0
numFailed = 0

' update files in dest from files in source
Sub UpdateFiles(source, dest)
    Set srcFolder = fso.GetFolder(source) 
    Set srcFiles = srcFolder.Files
    On Error Resume Next
    If Not fso.FolderExists(dest) Then
        fso.CreateFolder(dest)
        If Err Then
            If install Then
                WScript.Echo "Could not create " & dest & " (" & Err.Description & ")"
        Exit Sub
            End If
        End If
    End If
    For Each file in srcFiles
        numCopied = numCopied + 1
        elems = Split(file, "\")
        fileName = elems(UBound(elems))
    ' WScript.Echo file & " --- " & dest & "\" & fileName
        fso.CopyFile file, dest & "\" & fileName
        If Err Then
            If install Then
                WScript.Echo "Could not copy " & fileName & " (" & Err.Description & ")"
            End If
            numFailed = numFailed + 1
        End If
    Next
    ' recurse into subdirectories
    Set srcDirs = srcFolder.SubFolders
    For Each dir in srcDirs
        elems = Split(dir, "\")
        dirName = elems(UBound(elems))
        destDir = dest & "\" & dirName
        UpdateFiles dir, destDir
    Next
    On Error Goto 0
End Sub

' update one job dir
Sub UpdateJobDir(src, dest, dir)
    srcDir = src & "\" & dir
    destDir = dest & "\" & dir
    If (fso.FolderExists(srcDir)) Then
        UpdateFiles srcDir, destDir
    End If
End Sub

' update jobs for a specific module/folder
Sub UpdateJobs(src, dest, folder)
    UpdateJobDir src, dest, "batch_jobs\" & folder
    UpdateJobDir src, dest, "data_services\" & folder
    UpdateJobDir src, dest, "process_services\" & folder
End Sub

' update jobs for modules. folders is space separated.
Sub UpdateModule(name, folders)
    If install Then
        WScript.Echo "Updating " & name & " jobs..."
    End If
    numCopied = 0 
    folderList = split(folders, " ")
    For Each folder in folderList
        UpdateJobs jobSrc, jobsRoot, folder
    Next
    If install Then
        WScript.Echo "Updated " & numCopied & " jobs."
    End If
End Sub

' default to update only Web Studio modules
modList = "sasmdm"

' read update config file if it exists
If fso.FileExists(upCfg) Then
    Set file = fso.GetFile(upCfg)
    Set stream = file.OpenAsTextStream(1, 0)
    While Not stream.AtEndOfStream 
        line = stream.ReadLine
        If Left(line, 1) <> "#" Then
        ' not a comment
            fields = Split(line, "=")
            If UBound(fields) > 0 Then
                ' key=value line
                key = Trim(fields(0))
                value = Trim(fields(1))
                If (LCase(key) = "modules") Then
                    modList = value
                End If
            End If
        End If
    Wend
End If

' update jobs in server's working directories
If install Then
    WScript.Echo "Updating jobs in " & jobsRoot & "..."
End If
If InStr(modList, "sasmdm") Then
    UpdateModule "sasmdm", "sasmdm"
End If
If numFailed > 0 Then
    updateFailed = True
    If install Then
        WScript.Echo numFailed & " jobs could not be updated." 
    End If
End If

' results
If install Then
    If updateFailed Then
        WScript.Echo "Update failed."
    Else
        WScript.Echo "Updated MDM jobs."
    End If
Else 
    msgTitle = "Update MDM jobs"
    If updateFailed Then
        If numFailed > 0 Then
            addMsg = numFailed & " jobs could not be updated."
        End If
        MsgBox "The attempt to update MDM jobs failed. " & addMsg, 48, msgTitle
    Else
        MsgBox "Updated MDM jobs.", 64, msgTitle
    End If
End If

If updateFailed Then
    WScript.Quit 1
End If

